#!/usr/bin/perl
#From Michael's old perl scripts
#-------- 0. Import Lab::Measurement -------


use Lab::Measurement;
use File::Basename;
use POSIX qw(strftime);


our $AMP_I_DC = 1e-6;

my $gate_value = 0.0;

my $DC_Divider = 0.01;

my $AC_Divider = 0.001; #0.001 ist real 20190705
#my $AC_amp = 0.1; #auskommentiert am 28.5.2019

#-------- 1. Initialize Instruments --------

my $gate_source = Instrument('Yokogawa7651', 
    {
    connection_type => 'VISA_GPIB',
    gpib_address => 19,
    gate_protect => 0
    });

my $bias_source = Instrument('Yokogawa7651', 
    {
    connection_type => 'VISA_GPIB',
    gpib_address => 5,
    gate_protect => 0
    });

    
my $multimeter = Instrument('HP3458A',#HP34401A 
    {
    connection_type => 'VISA_GPIB',
    gpib_address => 21,
    #nplc => 0.1                  # integration time in number of powerline cylces [10*(1/50)]
    });

my $srs = Instrument('SR830',
	{
     connection_type => 'VISA_GPIB',
     gpib_address  => 16
	});	
my $AC_amp =$srs->get_amplitude() ;


my $IPS = Instrument('IPSStrunkDillFridge',{
	connection_type=>'VISA_GPIB',
    gpib_address  => 25,

});
#-------- 3. Define the Sweeps -------------


my $bias_sweep = Sweep('Voltage', 
    {
    mode => 'step',
    instrument => $bias_source,
    points => [-0.1,0.8],    # [starting point, target]
    stepwidth => [0.001], ##0.002
    rate => [0.1, 0.01],      # [rate to approach start, sweeping rate for measurement] in Volts/s
	#backsweep  => 1,
    jump => 1, 
    delay_before_loop => 10         # delay before Sweep begins in s  #60?
    });

 my $sweep_field = Sweep('Magnet', {
	instrument => $IPS,	
	mode => 'step',
	points => [-0.5,2.5],
	rate => [0.1,0.05],
	stepwidth => [0.005],
	use_persistentmode => 1,
	#number_of_points => [10],
	#interval => [0.5],
});   
    
#-------- 3. Create a DataFile -------------
my $point0 = @{$bias_sweep->{config}->{points}}[0];

my $pointN = @{$bias_sweep->{config}->{points}}[-1];


my $dirname = basename($0,".pl")."_".strftime "%d.%m.%Y", localtime;

my $DataFile = DataFile(basename($0,".pl")."_${point0} to ${pointN} at Gate = ${gate_value}_Majorana-5_CL4-GL-10_50mK.dat",$dirname);



$DataFile->add_column('Field');
$DataFile->add_column('Bias');
$DataFile->add_column('Current');
$DataFile->add_column('ACx');
$DataFile->add_column('ACy');
$DataFile->add_column('ACr');

$DataFile->add_plot({
    'type' => 'pm3d',
    'x-axis' => 'Field',
    'y-axis' => 'Bias', 
    'cb-axis' => 'Current',
    'refresh' => 'block'
   }
    );

$DataFile->add_plot({
    'type' => 'pm3d',
    'x-axis' => 'Field',
    'y-axis' => 'Bias', 
    'cb-axis' => 'ACx',
    'refresh' => 'block'
    }
    );	
    
#-------- 4. Measurement Instructions -------

my $my_measurement = sub {

    my $sweep = shift;

    my $bias = $bias_source->get_value({read_mode => 'cache'});
   # my $bias = $bias_source->get_value({read_mode => 'cache'});
    
    my $current = $multimeter->get_value();
	my $Field = @{$sweep_field->{config}->{points}}[$sweep_field->{iterator}];
	my ($ACvalue_X , $ACvalue_Y) = $srs->get_xy();
	my $acr = $ACvalue_X*25812/($AC_amp*$AC_Divider);
	
    $sweep->LOG({
        
		Field => $Field,
		Bias => $bias*$DC_Divider,
        Current => $current*($AMP_I_DC),
		ACx => $ACvalue_X*($AMP_I_DC),
		ACy => $ACvalue_Y*($AMP_I_DC),
		ACr => $acr*($AMP_I_DC)
        });
};


#-------- 5. Put everything together -------

$DataFile->add_measurement($my_measurement);

$bias_sweep->add_DataFile($DataFile);

my $frame=Frame();
$frame->add_master($sweep_field);
$frame->add_slave($bias_sweep);

$frame->start();

