#-------- 0. Import Lab::Measurement -------

use Lab::Measurement;
use File::Basename;
use POSIX qw(strftime);


our $AMP_I_DC = 1e-6;

my $gate_value = 0.0;		#Gate position

my $DC_Divider = 0.01;

my $AC_Divider = 0.001;
#my $AC_amp = 1; #am 7.12.2017 auskommentiert QPC, von 0.2 auf 1 geändert

#-------- 1. Initialize Instruments --------

my $voltage_backgate = Instrument('Yokogawa7651', 
    {
    connection_type => 'VISA_GPIB',
    gpib_address => 19,
    gate_protect => 0, 
    });
	
	my $voltage_bias = Instrument('Yokogawa7651', 
    {
    connection_type => 'VISA_GPIB',
    gpib_address => 5,
    gate_protect => 0, 
    });
	
	
 my $multimeter = Instrument('HP3458A', 
  {
  connection_type => 'VISA_GPIB',
  gpib_address => 21,
  #timeout => 1.5, #	idea of andreas 2018-03.06
  #nplc => 50                 # integration time in number of powerline cylces [10*(1/50)]
  });
	
	
my $srs = Instrument('SR830',
	{
     connection_type => 'VISA_GPIB',
     gpib_address  => 16
	});
my $AC_amp =$srs->get_amplitude() ;
	
#-------- 3. Define the Sweeps -------------

my $voltage_sweep = Sweep('Voltage', 
    {
    mode => 'step',
    instrument => $voltage_bias,
    points => [-0.8,0.8],    # [starting point, target]
    stepwidth => [0.0005],#0.01 0.0001
    rate => [0.1, 0.01],      # [rate to approach start, sweeping rate for measurement] in Volts/s
    #interval=>0.5
	#backsweep  => 1,
	jump => 1,
	delay_before_loop => 3         # delay before Sweep begins in s
    });

	
	
#-------- 3. Create a DataFile -------------

my $point0 = @{$bias_sweep->{config}->{points}}[0];

my $pointN = @{$bias_sweep->{config}->{points}}[-1];


my $dirname = basename($0,".pl")."_".strftime "%d.%m.%Y", localtime;

my $DataFile = DataFile(basename($0,".pl")."_${point0} to ${pointN} at Gate = ${gate_value}_Majorana-5_Through-CNT_0T_T-dep_50mK.dat",$dirname);

$DataFile->add_column('Voltage');
$DataFile->add_column('Current');
$DataFile->add_column('ACx');
$DataFile->add_column('ACy');
$DataFile->add_column('ACr');
#$DataFile->add_plot({
#    'x-axis' => 'Voltage',
#    'y-axis' => 'ACx',
#	'type' => 'lines'
#    }
#    );

 $DataFile->add_plot({
    'x-axis' => 'Voltage',
    'y-axis' => 'Current',
	'type' => 'lines'
   }
   );

$DataFile->add_plot({
    'x-axis' => 'Voltage',
    'y-axis' => 'ACr',
	'type' => 'lines'
    }
    );
   
#-------- 4. Measurement Instructions -------

my $my_measurement = sub {

    my $sweep = shift;

    my $voltage = $voltage_bias->get_value({read_mode => 'cache'});
    my $current = $multimeter->get_value();
	my ($ACvalue_X , $ACvalue_Y) = $srs->get_xy();
	
	my $acr=sqrt($ACvalue_X*$ACvalue_X+$ACvalue_Y*$ACvalue_Y)*25812/($AC_amp*$AC_Divider); # Calculate conductance in units of e^2/h
	
    $sweep->LOG({
        Voltage => $voltage*$DC_Divider,
        Current => $current*($AMP_I_DC),#hier war 3x in - 16.7.19
		ACx => $ACvalue_X*($AMP_I_DC),
		ACy => $ACvalue_Y*($AMP_I_DC),
		ACr	=> $acr*($AMP_I_DC)
        });
};


#-------- 5. Put everything together -------

$DataFile->add_measurement($my_measurement);

$voltage_sweep->add_DataFile($DataFile);

$voltage_sweep->start();

